@@ -46,6 +46,7 @@ OC.L10N.register(
     "Sorting" : "Orde",
     "Gravatar settings" : "Configuración de Gravatar",
     "Register" : "Rexistrase",
+    "Shared with me" : "Compartióse conmigo",
     "S/MIME" : "S/MIME",
     "About" : "Tocante a",
     "Keyboard shortcuts" : "Atayos del tecláu",
@@ -54,6 +55,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Unviar",
     "Refresh" : "Anovar",
+    "Ok" : "D'acuerdu",
     "Certificate updated" : "Anovóse'l certificáu",
     "Could not update certificate" : "Nun se pudo anovar el certificáu",
     "Send later" : "Unviar dempués",
@@ -103,14 +105,15 @@ OC.L10N.register(
     "Delete message" : "Desaniciar el mensaxe",
     "More actions" : "Más aiciones",
     "Back" : "Atrás",
-    "Create event" : "Crear un eventu",
     "Create task" : "Crear la xera",
     "Download message" : "Baxar el mensaxe",
     "Load more" : "Cargar más",
     "Report this bug" : "Informar d'esti fallu",
     "Event created" : "Creóse l'eventu",
     "Could not create event" : "Nun se pudo crear l'eventu",
+    "Create event" : "Crear un eventu",
     "All day" : "Tol día",
+    "Attendees" : "Asistentes",
     "Description" : "Descripción",
     "Create" : "Crear",
     "This event was updated" : "Esti eventu anovóse",
@@ -134,6 +137,10 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "dominiu",
     "Remove" : "Quitar",
+    "Today" : "Güei",
+    "Yesterday" : "Ayeri",
+    "Last week" : "La selmana anterior",
+    "Last month" : "El mes anterior",
     "Loading messages …" : "Cargando los mensaxes…",
     "Choose target folder" : "Escoyer la carpeta de destín",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
@@ -160,6 +167,7 @@ OC.L10N.register(
     "Move up" : "Xubir",
     "Move down" : "Baxar",
     "Show all folders" : "Amosar toles carpetes",
+    "Collapse folders" : "Contrayer carpetes",
     "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
     "Loading …" : "Cargando…",
     "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
@@ -274,6 +282,11 @@ OC.L10N.register(
     "Certificate" : "Certificáu",
     "Private key (optional)" : "Clave privada (opcional)",
     "Submit" : "Unviar",
+    "Guest" : "Convidáu",
+    "Group" : "Grupu",
+    "Shared" : "Compartióse",
+    "Shares" : "Comparticiones",
+    "Insert" : "Inxertar",
     "Account connected" : "Cuenta conectada",
     "You can close this window" : "Pues zarrar esta ventana",
     "All" : "Too",
@@ -297,18 +310,6 @@ OC.L10N.register(
     "Could not load the message" : "Nun se pudo cargar el mensaxe",
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
-    "The link leads to %s" : "L'enllaz lleva a %s",
-    "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
-    "Draft: " : "Borrador:",
-    "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
-    "Add mailbox" : "Amestar una bandexa",
-    "Mailbox name" : "Nome de la bandexa",
-    "Show all mailboxes" : "Amosar toles bandexes",
-    "Collapse mailboxes" : "Contrayer toles bandexes",
-    "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
-    "Delete mailbox" : "Desaniciar la bandexa",
-    "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
-    "Move mailbox" : "Mover la bandexa",
-    "Actions" : "Aiciones"
+    "The link leads to %s" : "L'enllaz lleva a %s"
 },
 "nplurals=2; plural=(n != 1);");
