@@ -116,6 +116,7 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdater",
+    "Ok" : "OK",
     "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
     "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
     "Send later" : "Send senere",
@@ -190,7 +191,6 @@ OC.L10N.register(
     "More actions" : "Flere handlinger",
     "Back" : "Tilbage",
     "Edit as new message" : "Rediger som ny besked",
-    "Create event" : "Opret begivenhed",
     "Create task" : "Opret opgave",
     "Download message" : "Download besked",
     "Load more" : "Hent flere",
@@ -203,10 +203,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Fravælg {number}","Fravælg {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Flyt {number} tråd","Flyt {number} tråde"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedhæftet fil","Videresend {number} som vedhæftet fil"],
+    "Mark as unread" : "Markér som ulæst",
+    "Mark as read" : "Markér som læst",
     "Report this bug" : "Rapporter denne fejl",
     "Event created" : "Begivenhed oprettet",
     "Could not create event" : "Begivenheden kunne ikke oprettes",
+    "Create event" : "Opret begivenhed",
     "All day" : "Hele dagen",
+    "Attendees" : "Deltagere",
     "Description" : "Beskrivelse",
     "Create" : "Opret",
     "This event was updated" : "Denne begivenhed blev opdateret",
@@ -229,6 +233,8 @@ OC.L10N.register(
     "More options" : "Flere muligheder",
     "Remove" : "Fjern",
     "email" : "e-mail",
+    "Today" : "I dag",
+    "Last week" : "Seneste uge",
     "Loading messages …" : "Indlæser beskeder...",
     "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
@@ -325,8 +331,6 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Reply all" : "Besvar alle",
     "Reply to sender only" : "Besvar kun afsender",
-    "Mark as unread" : "Markér som ulæst",
-    "Mark as read" : "Markér som læst",
     "Go to newest message" : "Gå til nyeste besked",
     "Translate from" : "Oversæt fra",
     "Translate to" : "Oversæt til",
@@ -370,6 +374,10 @@ OC.L10N.register(
     "Private key (optional)" : "Privat nøgle (valgfrit)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
     "Submit" : "Send",
+    "Group" : "Gruppe",
+    "Shared" : "Delt",
+    "Shares" : "Delinger",
+    "Insert" : "Indsæt",
     "Account connected" : "Kontoen er tilknyttet",
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
@@ -397,25 +405,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s",
-    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
-    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
-    "Draft: " : "Kladde:",
-    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
-    "Choose target mailbox" : "Vælg målpostkasse",
-    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
-    "Add mailbox" : "Tilføj postkasse",
-    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
-    "Show all mailboxes" : "Vis alle postkasser",
-    "Collapse mailboxes" : "Skjul postkasser ",
-    "Clear mailbox" : "Ryd postkasse",
-    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
-    "Add submailbox" : "Tilføj underpostkasse",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
-    "Search in mailbox" : "Søg i postkasse",
-    "New test" : "Nyeste test",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling"
+    "Continue to %s" : "Videre til %s"
 },
 "nplurals=2; plural=(n != 1);");
