@@ -113,6 +113,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "Ok" : "Ok",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
     "Could not update certificate" : "No se pudo actualizar el certificado",
@@ -197,7 +198,6 @@ OC.L10N.register(
     "More actions" : "Más acciones",
     "Back" : "Atrás",
     "Edit as new message" : "Editar como nuevo mensaje",
-    "Create event" : "Crear evento",
     "Create task" : "Crear tarea",
     "Download message" : "Descargar mensaje",
     "Load more" : "Cargar más",
@@ -210,10 +210,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["No seleccionar {number}","No seleccionar {number}","No seleccionar {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Mover {number} hilo","Mover {number} hilos","Mover {number} hilos"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Reenviar {number} como adjunto","Reenviar {number} como adjunto","Reenviar {number} como adjunto"],
+    "Mark as unread" : "Marcar como no leído",
+    "Mark as read" : "Marcar como leído",
     "Report this bug" : "Informar de este error",
     "Event created" : "Evento creado",
     "Could not create event" : "No se pudo crear el evento",
+    "Create event" : "Crear evento",
     "All day" : "Todo el día",
+    "Attendees" : "Asistentes",
     "Select calendar" : "Seleccionar calendario",
     "Description" : "Descripción",
     "Create" : "Crear",
@@ -242,6 +246,10 @@ OC.L10N.register(
     "email" : "correo electrónico",
     "Itinerary for {type} is not supported yet" : "El itinerario de {type} aún no es compatible",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
+    "Last hour" : "Última hora",
+    "Today" : "Hoy",
+    "Last week" : "La semana pasada",
+    "Last month" : "El mes pasado",
     "Loading messages …" : "Cargando mensajes...",
     "Choose target folder" : "Selecciona la carpeta de destino.",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
@@ -403,8 +411,6 @@ OC.L10N.register(
     "Reply to sender only" : "Responder solo al remitente",
     "Mark as unfavorite" : "Marcar como no favorito",
     "Mark as favorite" : "Marcar como favorito",
-    "Mark as unread" : "Marcar como no leído",
-    "Mark as read" : "Marcar como leído",
     "Unsubscribe via link" : "Cancelar suscripción mediante enlace",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Cancelar la suscripción detendrá todos los mensajes de la lista de correo {sender}",
     "Send unsubscribe email" : "Enviar correo electrónico de cancelación de suscripción",
@@ -535,6 +541,10 @@ OC.L10N.register(
     "Private key (optional)" : "Clave privada (opcional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La clave privada solo es necesaria si tienes la intención de enviar correos electrónicos firmados y cifrados usando este certificado.",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
+    "Insert" : "Insertar",
     "Account connected" : "Cuenta conectada",
     "You can close this window" : "Puedes cerrar esta ventana",
     "Connect your mail account" : "Conecta tu cuenta de correo",
@@ -571,29 +581,6 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
-    "Continue to %s" : "Continuar a %s",
-    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
-    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
-    "Draft: " : "Borrador: ",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
-    "Choose target mailbox" : "Selecciona el buzón de destino",
-    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
-    "Add mailbox" : "Agregar buzón",
-    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
-    "Show all mailboxes" : "Mostrar todos los buzones",
-    "Collapse mailboxes" : "Colapsar buzones",
-    "Clear mailbox" : "Limpiar buzón",
-    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
-    "Delete mailbox" : "Eliminar buzón",
-    "Delete mailbox {name}" : "Eliminar buzón {name}",
-    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
-    "Add submailbox" : "Agregar sub-buzón",
-    "Move mailbox" : "Mover buzón",
-    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
-    "Search in mailbox" : "Buscar en el correo",
-    "Actions" : "Acciones",
-    "New action" : "Nueva acción"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
