@@ -259,14 +259,15 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Set custom snooze" : "Configurar pausa personalizada",
     "Edit as new message" : "Editar como nuevo mensaje",
-    "Create event" : "Crear evento",
     "Create task" : "Crear tarea",
     "Download message" : "Descargar mensaje",
     "Load more" : "Cargar más",
     "Report this bug" : "Reportar este bug",
     "Event created" : "Evento creado",
     "Could not create event" : "No se pudo crear el evento",
+    "Create event" : "Crear evento",
     "All day" : "Todo el día",
+    "Attendees" : "Asistentes",
     "Select calendar" : "Seleccionar calendario",
     "Description" : "Descripción",
     "Create" : "Crear",
@@ -299,6 +300,10 @@ OC.L10N.register(
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
+    "Last hour" : "Última hora",
+    "Today" : "Hoy",
+    "Last week" : "Semana pasada",
+    "Last month" : "Mes pasado",
     "Loading messages …" : "Cargando mensajes...",
     "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
@@ -368,6 +373,10 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
+    "Insert" : "Insertar",
     "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
@@ -392,17 +401,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Mailbox search" : "Búsqueda en el buzón de correo",
-    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
-    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
-    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
-    "Draft: " : "Borrador:",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
-    "Choose target mailbox" : "Escoger buzón de destino",
-    "Clear mailbox" : "Vaciar buzón",
-    "Actions" : "Acciones"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
