@@ -141,6 +141,9 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "Registreeri mailto: linke avava rakendusena",
     "Register" : "Registreeru",
+    "Text blocks" : "Tekstiplokid",
+    "Create a new text block" : "Koosta uus tekstiplokk",
+    "Shared with me" : "Jagatud minuga",
     "Privacy and security" : "Privaatsus ja turvalisus",
     "Data collection consent" : "Nõusolek andmete kogumiseks",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Luba rakendusel koguda andmeid sinu kasutusharjumuste kohta. Nende andmete alusel rakendus kohendab oma seadistusi. Kogutud andmed on säilitatud vaid kohalikus serveris.",
@@ -152,6 +155,7 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "Mailvelope on selle domeeni puhul kasutusel!",
     "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
+    "Install Mailvelope browser extension" : "Paigalda Mailvelope'i brauserilaiendus",
     "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!",
     "Assistance features" : "Abilise funktsionaalsused",
     "About" : "Rakenduse teave",
@@ -167,6 +171,10 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
+    "New text block" : "Uus tekstiplokk",
+    "Title of the text block" : "Tekstiploki pealkiri",
+    "Content of the text block" : "Tekstiploki sisu",
+    "Ok" : "Sobib",
     "No certificate" : "Sertifikaati pole",
     "Certificate updated" : "Sertifikaat on uuendatud",
     "Could not update certificate" : "Sertifikaadi uuendamine ei õnnestunud",
@@ -278,7 +286,7 @@ OC.L10N.register(
     "Back" : "Tagasi",
     "Set custom snooze" : "Vali edasilükkamise aeg",
     "Edit as new message" : "Muuda uue kirjana",
-    "Create event" : "Lisa sündmus",
+    "Reply with meeting" : "Vasta saates koosoleku teavet",
     "Create task" : "Loo ülesanne",
     "Download message" : "Laadi kiri alla",
     "Load more" : "Laadi veel",
@@ -294,10 +302,15 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Muuda {number} kirja silte","Muuda {number} kirja silte"],
     "_Move {number} thread_::_Move {number} threads_" : ["Teisalda {number} jutulõng","Teisalda {number} jutulõnga"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Edasta {number} kiri manusena","Edasta {number} kirja manusena"],
+    "Mark as unread" : "Märgi mitteloetuks",
+    "Mark as read" : "Märgi loetuks",
     "Report this bug" : "Teata sellest veast",
     "Event created" : "Sündmus on loodud",
     "Could not create event" : "Sündmuse loomine ei õnnestunud",
+    "Create event" : "Lisa sündmus",
     "All day" : "Kogu päev",
+    "Attendees" : "Osalejad",
+    "You can only invite attendees if your account has an email address set" : "Sa saad kutsuda osalejaid vaid siis, kui sinu kasutajakontole on lisatud e-posti aadress",
     "Select calendar" : "Vali kalender",
     "Description" : "Kirjeldus",
     "Create" : "Loo",
@@ -335,6 +348,12 @@ OC.L10N.register(
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Sul pole õigusi selle kirja arhiveerimiseks ega siit kaustast kustutamiseks või teisaldamiseks",
     "Your IMAP server does not support storing the seen/unseen state." : "Sinu e-posti server ei luba salvestada kirjade nähtud/mittenähtud olekuid.",
     "Could not mark message as seen/unseen" : "Ei õnnestunud märkida kirja nähtuks/mittenähtuks",
+    "Last hour" : "Viimase tunni jooksul",
+    "Today" : "Täna",
+    "Yesterday" : "Eile",
+    "Last week" : "Eelmisel nädalal",
+    "Last month" : "Eelmisel kuul",
+    "Older" : "Vanemad",
     "Could not open folder" : "Kausta avamine ei õnnestunud",
     "Loading messages …" : "Laadin kirju…",
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
@@ -393,6 +412,7 @@ OC.L10N.register(
     "Remove account" : "Eemalda konto",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "E-posti konto {email} ja tema puhverdatud andmed eemaldatakse siit Nextcloudi serverist, kuid mitte sinu e-postiteenuse pakkuja juurest.",
     "Remove {email}" : "Eemalda fail: „{email}“",
+    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Selle konto kasutamiseks palun logi sisse salasõnaga. Praegune sessioon kasutab salasõnata tuvastamist, milleks võib olla SSO, WebAuthn, vms.",
     "Show only subscribed folders" : "Näita vaid tellitud kaustu",
     "Add folder" : "Lisa kaust",
     "Folder name" : "Kausta nimi",
@@ -401,6 +421,7 @@ OC.L10N.register(
     "Move down" : "Liiguta allapoole",
     "Show all subscribed folders" : "Näita kõiki tellitud kaustu",
     "Show all folders" : "Näita kõiki kaustu",
+    "Collapse folders" : "Ahenda kaustad",
     "_{total} message_::_{total} messages_" : ["{total} kiri","{total} kirja"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
     "Loading …" : "Laadin...",
@@ -423,6 +444,7 @@ OC.L10N.register(
     "Subscribed" : "Tellitud",
     "Sync in background" : "Sünkroniseeri taustal",
     "Outbox" : "Saadetud kirjad",
+    "Translate this message to {language}" : "Tõlgi see e-kiri sihtkeelde: {language}",
     "New message" : "Uus kiri",
     "Edit message" : "Muuda kirja",
     "Draft" : "Kavand",
@@ -564,8 +586,6 @@ OC.L10N.register(
     "Reply to sender only" : "Vasta vaid saatjale",
     "Mark as unfavorite" : "Märgi mittelemmikuks",
     "Mark as favorite" : "Märgi lemmikuks",
-    "Mark as unread" : "Märgi mitteloetuks",
-    "Mark as read" : "Märgi loetuks",
     "Unsubscribe via link" : "Loobu tellimusest lingi kaudu",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Tellimusest loobudes sa enam ei saa kirju postiloendist {sender}",
     "Send unsubscribe email" : "Saada loobumiskiri",
@@ -659,6 +679,9 @@ OC.L10N.register(
     "For more details, please click here to open our documentation." : "Lisateavet leiad meie dokumentatsioonist ↗.",
     "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
     "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Algne kiri lisatakse manusena „message/rfc822“ tüüpi failina.",
+    "\"Mark as Spam\" Email Address" : "„Märgitud rämpspostiks“ e-posti aadressid",
+    "\"Mark Not Junk\" Email Address" : "„Pole rämpspost“ e-posti aadressid",
     "Reset" : "Lähtesta",
     "Google integration configured" : "Google'i e-postiteenuste lõiming on seadistatud",
     "Could not configure Google integration" : "Google'i e-postiteenuste lõimingu seadistamine ei õnnestunud",
@@ -713,6 +736,25 @@ OC.L10N.register(
     "Private key (optional)" : "Privaatvõti (kui vaja)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Privaatvõtit on vaja vaid siis, kui plaanid selle sertifikaadiga saata allkirjastatud ja krüptitud e-kirju.",
     "Submit" : "Saada",
+    "No text blocks available" : "Ühtegi tekstiplokki pole saadaval",
+    "Text block deleted" : "Tekstiplokk on kustutatud",
+    "Failed to delete text block" : "Tekstiploki kustutamine ei õnnestunud",
+    "Text block shared with {sharee}" : "Tekstiplokk on jagatud kasutajaga {sharee}",
+    "Failed to share text block with {sharee}" : "Tekstiploki jagamine kasutajaga {sharee} ei õnnestunud",
+    "Share deleted for {name}" : "{name} tekstiploki jagamine on eemaldatud",
+    "Failed to delete share with {name}" : "{name} tekstiploki jagamise eemaldamine ei õnnestunud",
+    "Guest" : "Külaline",
+    "Group" : "Grupp",
+    "Failed to save text block" : "Tekstiploki salvestamine ei õnnestunud",
+    "Shared" : "Jagatud",
+    "Edit {title}" : "Muuda: {title}",
+    "Delete {title}" : "Kustuta: {title}",
+    "Edit text block" : "Muuda tekstiplokki",
+    "Shares" : "Jaoskaustad",
+    "Search for users or groups" : "Otsi kasutajaid või gruppe",
+    "Choose a text block to insert at the cursor" : "Vali kursori asukohast alates lisatav tekstiplokk",
+    "Insert" : "Lisa",
+    "Insert text block" : "Sisesta tekstiplokk",
     "Account connected" : "Konto ühendatud",
     "You can close this window" : "Võid selle akna sulgeda.",
     "Connect your mail account" : "Ühenda oma e-posti kontoga",
@@ -753,42 +795,6 @@ OC.L10N.register(
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
-    "Continue to %s" : "Jätka siia: %s",
-    "Mailbox search" : "Postkasti otsing",
-    "Install Mailvelope browser extension by clicking here" : "Klõpside siia paigalda Mailvelope'i brauserilaiendus",
-    "No messages in this mailbox" : "Selles postkastis pole kirju",
-    "No trash mailbox configured" : "Prügikasti kaust on määramata",
-    "Draft: " : "Kavand:",
-    "To archive a message please configure an archive mailbox in account settings" : "Kui tahad kirju arhiveerida, pead esmalt seadistustest valima arhiivikausta",
-    "Could not open mailbox" : "Postkasti avamine ei õnnestunud",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekseering sinu kirju. Kui postkastid on väga suured, siis võib kuluda natuke aega.",
-    "Choose target mailbox" : "Vali sihtpostkast",
-    "Show only subscribed mailboxes" : "Näita vaid tellitud postkaste",
-    "Add mailbox" : "Lisa postkast",
-    "Mailbox name" : "Postkasti nimi",
-    "Show all subscribed mailboxes" : "Näita kõiki tellitud postkaste",
-    "Show all mailboxes" : "Näita kõiki postkaste",
-    "Collapse mailboxes" : "Ahenda postkastid",
-    "Clear mailbox" : "Tühjenda postkast",
-    "The mailbox and all messages in it will be deleted." : "Postkast ja kõik temas leiduvad kirjad saavad järgnevaga kustutatud.",
-    "Delete mailbox" : "Kustuta postkast",
-    "Delete mailbox {name}" : "Kustuta postkast: {name}",
-    "Mark all messages of this mailbox as read" : "Märgi kõik selle postkasti kirjad loetuks",
-    "Add submailbox" : "Lisa alampostkast",
-    "Move mailbox" : "Teisalda postkast",
-    "Repair mailbox" : "Paranda postkasti",
-    "No sent mailbox configured. Please pick one in the account settings." : "Väljuvate kirjade postkast on seadistamata. Palun see seda kasutajakonto seadistustes.",
-    "Could not copy to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
-    "Copy to \"Sent\" Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
-    "Copy to Sent Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
-    "Search in mailbox" : "Otsi postkastist",
-    "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
-    "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
-    "Tests" : "Testid",
-    "New test" : "Uus test",
-    "Actions" : "Tegevused",
-    "New action" : "Uus tegevus",
-    "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
-    "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud"
+    "Continue to %s" : "Jätka siia: %s"
 },
 "nplurals=2; plural=(n != 1);");
