@@ -108,6 +108,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
     "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
     "Register" : "ثبت‌نام",
+    "Shared with me" : "Shared with me",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
     "Manage S/MIME certificates" : "Manage S/MIME certificates",
@@ -124,6 +125,7 @@ OC.L10N.register(
     "Search" : "جستجو",
     "Send" : "ارسال",
     "Refresh" : "تازه‌سازی",
+    "Ok" : "باشه",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
     "Could not update certificate" : "Could not update certificate",
@@ -220,7 +222,6 @@ OC.L10N.register(
     "Back" : "بازگشت",
     "Set custom snooze" : "Set custom snooze",
     "Edit as new message" : "Edit as new message",
-    "Create event" : "Create event",
     "Create task" : "وظیفه ایجاد کنید",
     "Download message" : "Download message",
     "Load more" : "Load more",
@@ -233,10 +234,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Unselect {number}","Unselect {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
+    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
+    "Mark as read" : "علامت به عنوان خوانده‌شده",
     "Report this bug" : "گزارش این اشکال",
     "Event created" : "Event created",
     "Could not create event" : "رویداد ایجاد نشد",
+    "Create event" : "Create event",
     "All day" : "تمام روز",
+    "Attendees" : "شرکت کنندگان",
     "Select calendar" : "Select calendar",
     "Description" : "شرح",
     "Create" : "ساخت",
@@ -265,6 +270,10 @@ OC.L10N.register(
     "email" : "ایمیل",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
+    "Last hour" : "Last hour",
+    "Today" : "امروز.",
+    "Last week" : "هفته گذشته",
+    "Last month" : "ماه گذشته",
     "Loading messages …" : "Loading messages …",
     "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
     "No more submailboxes in here" : "No more submailboxes in here",
@@ -433,8 +442,6 @@ OC.L10N.register(
     "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
     "Mark as unfavorite" : "Mark as unfavorite",
     "Mark as favorite" : "Mark as favorite",
-    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
-    "Mark as read" : "علامت به عنوان خوانده‌شده",
     "Unsubscribe via link" : "Unsubscribe via link",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
     "Send unsubscribe email" : "Send unsubscribe email",
@@ -560,6 +567,10 @@ OC.L10N.register(
     "Private key (optional)" : "Private key (optional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
     "Submit" : "ارسال",
+    "Group" : "گروه",
+    "Shared" : "به اشتراک گذاشته شده ",
+    "Shares" : "اشتراک گذاری ها",
+    "Insert" : "Insert",
     "Account connected" : "حساب کاربری متصل شد",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
@@ -596,29 +607,6 @@ OC.L10N.register(
     "Redirect" : "تغییر مسیر",
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "ادامه دهید%s",
-    "No messages in this mailbox" : "No messages in this mailbox",
-    "No trash mailbox configured" : "No trash mailbox configured",
-    "Draft: " : "پیش نویس:",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
-    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
-    "Choose target mailbox" : "Choose target mailbox",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
-    "Collapse mailboxes" : "Collapse mailboxes",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
-    "Move mailbox" : "Move mailbox",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
-    "Search in mailbox" : "Search in mailbox",
-    "Actions" : "کنش‌ها",
-    "New action" : "New action"
+    "Continue to %s" : "ادامه دهید%s"
 },
 "nplurals=2; plural=(n > 1);");
