@@ -91,6 +91,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Register" : "Rekisteröidy",
+    "Shared with me" : "Jaettu kanssasi",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
@@ -108,6 +109,7 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
+    "Ok" : "Ok",
     "No certificate" : "Ei varmennetta",
     "Certificate updated" : "Varmenne päivitetty",
     "Could not update certificate" : "Varmennetta ei voitu päivittää",
@@ -200,17 +202,20 @@ OC.L10N.register(
     "Back" : "Takaisin",
     "Set custom snooze" : "Aseta mukautettu torkutus",
     "Edit as new message" : "Muokkaa uutena viestinä",
-    "Create event" : "Luo tapahtuma",
     "Create task" : "Luo tehtävä",
     "Download message" : "Lataa viesti",
     "Load more" : "Lataa lisää",
     "_Mark {number} read_::_Mark {number} read_" : ["Merkitse {number} luetuksi","Merkitse {number} luetuksi"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Merkitse {number} lukemattomaksi","Merkitse {number} lukemattomaksi"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Merkitse {number} tärkeäksi","Merkitse {number} tärkeäksi"],
+    "Mark as unread" : "Merkitse lukemattomaksi",
+    "Mark as read" : "Merkitse luetuksi",
     "Report this bug" : "Ilmoita viasta",
     "Event created" : "Tapahtuma luotu",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
+    "Create event" : "Luo tapahtuma",
     "All day" : "Koko päivä",
+    "Attendees" : "Osallistujat",
     "Select calendar" : "Valitse kalenteri",
     "Description" : "Kuvaus",
     "Create" : "Luo",
@@ -235,6 +240,10 @@ OC.L10N.register(
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
+    "Last hour" : "Viime tunti",
+    "Today" : "Tänään",
+    "Last week" : "Viime viikko",
+    "Last month" : "Viime kuukausi",
     "Loading messages …" : "Ladataan viestejä …",
     "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
@@ -379,8 +388,6 @@ OC.L10N.register(
     "Unsubscribe" : "Peruuta tilaus",
     "Reply to sender only" : "Vastaa vain lähettäjälle",
     "Mark as favorite" : "Merkitse suosikiksi",
-    "Mark as unread" : "Merkitse lukemattomaksi",
-    "Mark as read" : "Merkitse luetuksi",
     "The message could not be translated" : "Viestiä ei voitu kääntää",
     "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
     "Translation could not be copied" : "Käännöstä ei voitu kopioida",
@@ -458,6 +465,10 @@ OC.L10N.register(
     "Certificate" : "Varmenne",
     "Private key (optional)" : "Yksityinen avain (valinnainen)",
     "Submit" : "Lähetä",
+    "Group" : "Ryhmä",
+    "Shared" : "Jaettu",
+    "Shares" : "Jaot",
+    "Insert" : "Lisää",
     "Account connected" : "Tili yhdistetty",
     "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
@@ -492,24 +503,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
-    "Continue to %s" : "Jatka sivulle %s",
-    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
-    "Draft: " : "Luonnos: ",
-    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
-    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
-    "Add mailbox" : "Lisää postilaatikko",
-    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
-    "Show all mailboxes" : "Näytä kaikki postilaatikot",
-    "Collapse mailboxes" : "Supista postilaatikot",
-    "Clear mailbox" : "Tyhjennä postilaatikko",
-    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
-    "Delete mailbox" : "Poista postilaatikko",
-    "Delete mailbox {name}" : "Poista postilaatikko {name}",
-    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
-    "Add submailbox" : "Lisää alipostilaatikko",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
-    "Actions" : "Toiminnot",
-    "New action" : "Uusi toiminto"
+    "Continue to %s" : "Jatka sivulle %s"
 },
 "nplurals=2; plural=(n != 1);");
