@@ -112,6 +112,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "Register as application for mail links",
     "Register" : "Register",
+    "Shared with me" : "Shared with me",
     "Data collection consent" : "Data collection consent",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
@@ -131,6 +132,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Refresh",
+    "Ok" : "Ok",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
     "Could not update certificate" : "Could not update certificate",
@@ -232,7 +234,6 @@ OC.L10N.register(
     "Back" : "Back",
     "Set custom snooze" : "Set custom snooze",
     "Edit as new message" : "Edit as new message",
-    "Create event" : "Create event",
     "Create task" : "Create task",
     "Download message" : "Download message",
     "Load more" : "Load more",
@@ -248,10 +249,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Edit tags for {number}","Edit tags for {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
+    "Mark as unread" : "Mark as unread",
+    "Mark as read" : "Mark as read",
     "Report this bug" : "Report this bug",
     "Event created" : "Event created",
     "Could not create event" : "Could not create event",
+    "Create event" : "Create event",
     "All day" : "All day",
+    "Attendees" : "Attendees",
     "Select calendar" : "Select calendar",
     "Description" : "Description",
     "Create" : "Create",
@@ -280,6 +285,10 @@ OC.L10N.register(
     "email" : "email",
     "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "Last week" : "Last week",
+    "Last month" : "Last month",
     "Loading messages …" : "Loading messages …",
     "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
@@ -335,7 +344,6 @@ OC.L10N.register(
     "Saving" : "Saving",
     "Move up" : "Move up",
     "Move down" : "Move down",
-    "Collapse mailboxes" : "Collapse mailboxes",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
     "Loading …" : "Loading …",
@@ -458,8 +466,6 @@ OC.L10N.register(
     "Reply to sender only" : "Reply to sender only",
     "Mark as unfavorite" : "Mark as unfavorite",
     "Mark as favorite" : "Mark as favorite",
-    "Mark as unread" : "Mark as unread",
-    "Mark as read" : "Mark as read",
     "Unsubscribe via link" : "Unsubscribe via link",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
     "Send unsubscribe email" : "Send unsubscribe email",
@@ -593,6 +599,10 @@ OC.L10N.register(
     "Private key (optional)" : "Private key (optional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
     "Submit" : "Submit",
+    "Guest" : "Guest",
+    "Group" : "Group",
+    "Shared" : "Shared",
+    "Shares" : "Shares",
     "Account connected" : "Account connected",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "Connect your mail account",
@@ -630,30 +640,6 @@ OC.L10N.register(
     "Redirect" : "Redirect",
     "The link leads to %s" : "The link leads to %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "Continue to %s",
-    "Mailbox search" : "Mailbox search",
-    "Install Mailvelope browser extension by clicking here" : "Install Mailvelope browser extension by clicking here",
-    "No messages in this mailbox" : "No messages in this mailbox",
-    "No trash mailbox configured" : "No trash mailbox configured",
-    "Draft: " : "Draft: ",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
-    "Could not open mailbox" : "Could not open mailbox",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexing your messages. This can take a bit longer for larger mailboxes.",
-    "Choose target mailbox" : "Choose target mailbox",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
-    "Mailbox name" : "Mailbox name",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
-    "Move mailbox" : "Move mailbox",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
-    "Search in mailbox" : "Search in mailbox",
-    "Actions" : "Actions"
+    "Continue to %s" : "Continue to %s"
 },
 "nplurals=2; plural=(n!=1);");
