@@ -128,6 +128,7 @@ OC.L10N.register(
     "Search" : "검색",
     "Send" : "보내기",
     "Refresh" : "새로 고침",
+    "Ok" : "확인",
     "No certificate" : "인증서 없음",
     "Certificate updated" : "인증서 갱신됨",
     "Could not update certificate" : "인증서를 갱신할 수 없음",
@@ -228,7 +229,6 @@ OC.L10N.register(
     "Back" : "뒤로",
     "Set custom snooze" : "사용자 지정 다시 알림 사용",
     "Edit as new message" : "새 메시지로 편집",
-    "Create event" : "일정 만들기",
     "Create task" : "작업 만들기",
     "Download message" : "메시지 다운로드",
     "Load more" : "더 불러오기",
@@ -244,10 +244,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number}의 태그 편집"],
     "_Move {number} thread_::_Move {number} threads_" : ["쓰레드 {number} 이동"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number}을(를) 첨부파일로 전달"],
+    "Mark as unread" : "읽지 않은 것으로 표시",
+    "Mark as read" : "읽은 것으로 표시",
     "Report this bug" : "이 오류 보고",
     "Event created" : "일정 생성됨",
     "Could not create event" : "일정을 생성할 수 없음",
+    "Create event" : "일정 만들기",
     "All day" : "하루 종일",
+    "Attendees" : "참석자",
     "Select calendar" : "달력 선택",
     "Description" : "설명",
     "Create" : "생성",
@@ -275,6 +279,8 @@ OC.L10N.register(
     "Remove" : "삭제",
     "email" : "이메일",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "이 메시지를 보관 폴더로 옮기거나 현재 폴더에서 삭제할 수 없습니다",
+    "Today" : "오늘",
+    "Last week" : "저번 주",
     "Loading messages …" : "메시지를 불러오는 중 ...",
     "Choose target folder" : "폴더 선택",
     "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
@@ -455,8 +461,6 @@ OC.L10N.register(
     "Reply to sender only" : "발신자에게만 답장",
     "Mark as unfavorite" : "즐겨찾기에서 해제",
     "Mark as favorite" : "즐겨찾기로 표시",
-    "Mark as unread" : "읽지 않은 것으로 표시",
-    "Mark as read" : "읽은 것으로 표시",
     "Unsubscribe via link" : "링크로 구독 해지",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "구독 해지는 메일링 리스트 {sender}이(가) 보내는 모든 메시지의 발신을 정지합니다",
     "Send unsubscribe email" : "구독 해지 이메일 보내기",
@@ -592,6 +596,9 @@ OC.L10N.register(
     "Private key (optional)" : "개인 키 (선택사항)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "개인 키는 이 인증서를 사용하여 서명하거나 암호화한 이메일을 보낼 때만 사용됩니다",
     "Submit" : "제출",
+    "Shared" : "공유됨",
+    "Shares" : "공유",
+    "Insert" : "삽입",
     "Account connected" : "계정 연결됨",
     "You can close this window" : "윈도우를 닫으셔도 됩니다",
     "Connect your mail account" : "메일 계정에 연결",
@@ -629,31 +636,6 @@ OC.L10N.register(
     "Redirect" : "넘겨주기",
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
-    "Continue to %s" : "%s(으)로 이동",
-    "Mailbox search" : "편지함 검색",
-    "Install Mailvelope browser extension by clicking here" : "여기를 눌러 Mailvelope 브라우저 확장기능을 설치하십시오",
-    "No messages in this mailbox" : "이 편지함에 메시지가 없음",
-    "No trash mailbox configured" : "휴지통 편지함이 설정되지 않음",
-    "Draft: " : "초안:",
-    "To archive a message please configure an archive mailbox in account settings" : "메일을 보관하기 위해서는 계정 설정에서 보관 편지함을 설정하십시오",
-    "Could not open mailbox" : "편지함을 열 수 없음",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "메시지를 색인 중입니다. 편지함이 클 경우 오래 걸릴 수 있습니다.",
-    "Choose target mailbox" : "대상 편지함 선택",
-    "Show only subscribed mailboxes" : "구독 중인 편지함만 표시",
-    "Add mailbox" : "편지함 추가",
-    "Mailbox name" : "편지함 이름",
-    "Show all subscribed mailboxes" : "구독 중인 모든 편지함 표시",
-    "Show all mailboxes" : "모든 편지함 표시",
-    "Collapse mailboxes" : "편지함 접기",
-    "Clear mailbox" : "편지함 비우기",
-    "The mailbox and all messages in it will be deleted." : "편지함과 해당 편지함의 모든 메시지가 삭제됩니다",
-    "Delete mailbox" : "편지함 삭제",
-    "Delete mailbox {name}" : "편지함 {name} 비우기",
-    "Mark all messages of this mailbox as read" : "편지함에 있는 모든 메시지를 읽음 처리하기",
-    "Add submailbox" : "하위 편지함 추가",
-    "Move mailbox" : "편지함 이동",
-    "No sent mailbox configured. Please pick one in the account settings." : "보낸 편지함이 설정되지 않았습니다. 계정 설정에서 지정하십시오.",
-    "Search in mailbox" : "편지함에서 검색",
-    "Actions" : "동작"
+    "Continue to %s" : "%s(으)로 이동"
 },
 "nplurals=1; plural=0;");
