@@ -107,6 +107,7 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
+    "Ok" : "Gerai",
     "Certificate updated" : "Liudijimas atnaujintas",
     "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
     "{commonName} - Valid until {expiryDate}" : "{commonName} – Galioja iki {expiryDate}",
@@ -180,16 +181,19 @@ OC.L10N.register(
     "More actions" : "Daugiau veiksmų",
     "Back" : "Atgal",
     "Edit as new message" : "Taisyti kaip naują laišką",
-    "Create event" : "Sukurti įvykį",
     "Create task" : "Sukurti užduotį",
     "Download message" : "Atsisiųsti laišką",
     "Load more" : "Įkelti daugiau",
     "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
+    "Mark as unread" : "Žymėti kaip neskaitytą",
+    "Mark as read" : "Žymėti kaip skaitytą",
     "Report this bug" : "Pranešti apie šią klaidą",
     "Event created" : "Įvykis sukurtas",
     "Could not create event" : "Nepavyko sukurti įvykio",
+    "Create event" : "Sukurti įvykį",
     "All day" : "Visą dieną",
+    "Attendees" : "Kviestiniai",
     "Description" : "Aprašas",
     "Create" : "Sukurti",
     "This event was updated" : "Šis įvykis buvo atnaujintas",
@@ -208,6 +212,10 @@ OC.L10N.register(
     "Remove" : "Šalinti",
     "email" : "elektroninis paštas",
     "Add internal address" : "Pridėti vidinį adresą",
+    "Last hour" : "Paskutinė valanda",
+    "Today" : "Šiandien",
+    "Last week" : "Praeitą savaitę",
+    "Last month" : "Praeitą mėnesį",
     "Loading messages …" : "Įkeliami laiškai…",
     "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Important info" : "Svarbi informacija",
@@ -330,8 +338,6 @@ OC.L10N.register(
     "Disable reminder" : "Išjungti priminimą",
     "Unsubscribe" : "Atsisakyti prenumeratos",
     "Reply to sender only" : "Atsakyti tik siuntėjui",
-    "Mark as unread" : "Žymėti kaip neskaitytą",
-    "Mark as read" : "Žymėti kaip skaitytą",
     "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
     "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
@@ -404,6 +410,8 @@ OC.L10N.register(
     "PEM Certificate" : "PEM liudijimas",
     "Certificate" : "Liudijimas",
     "Submit" : "Pateikti",
+    "Shared" : "Bendrinama",
+    "Shares" : "Viešiniai",
     "Account connected" : "Paskyra prijungta",
     "You can close this window" : "Galite užverti šį langą",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
@@ -436,25 +444,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
-    "Continue to %s" : "Tęsti į %s",
-    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
-    "Draft: " : "Juodraštis: ",
-    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
-    "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
-    "Add mailbox" : "Pridėti pašto dėžutę",
-    "Mailbox name" : "Pašto dėžutės pavadinimas",
-    "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
-    "Show all mailboxes" : "Rodyti visas pašto dėžutes",
-    "Collapse mailboxes" : "Suskleisti pašto dėžutes",
-    "Clear mailbox" : "Išvalyti pašto dėžutę",
-    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
-    "Delete mailbox" : "Ištrinti pašto dėžutę",
-    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
-    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
-    "Move mailbox" : "Perkelti pašto dėžutę",
-    "Search in mailbox" : "Ieškoti pašto dėžutėje",
-    "Actions" : "Veiksmai",
-    "New action" : "Naujas veiksmas"
+    "Continue to %s" : "Tęsti į %s"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
