@@ -55,6 +55,7 @@ OC.L10N.register(
     "Search" : "Meklēt",
     "Send" : "Sūtīt",
     "Refresh" : "Atsvaidzināt",
+    "Ok" : "Labi",
     "From" : "No",
     "Select account" : "Izvēlieties kontu",
     "To" : "Līdz",
@@ -73,9 +74,10 @@ OC.L10N.register(
     "Read" : "Lasīt",
     "Edit tags" : "Labot birkas",
     "Back" : "Atpakaļ",
-    "Create event" : "Izveidot notikumu",
     "Load more" : "Ielādēt vairāk",
+    "Create event" : "Izveidot notikumu",
     "All day" : "Visas dienas",
+    "Attendees" : "Dalībnieki",
     "Description" : "Apraksts",
     "Create" : "Izveidot",
     "Select" : "Atzīmēt",
@@ -85,6 +87,7 @@ OC.L10N.register(
     "More options" : "Vairāk iespēju",
     "Remove" : "Noņemt",
     "email" : "e-pasts",
+    "Today" : "Šodien",
     "Other" : "Cits",
     "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
     "Forward" : "Turpināt",
@@ -92,7 +95,7 @@ OC.L10N.register(
     "View source" : "Skatīt avotu",
     "Unnamed" : "Nenosaukts",
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
-    "Import into calendar" : "Importēt kalendārā",
+    "Import into calendar" : "Ievietot kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
     "Save all to Files" : "Saglabāt visu uz Datnes",
@@ -105,6 +108,7 @@ OC.L10N.register(
     "Folder name" : "Mapes nosaukums",
     "Saving" : "Saglabā",
     "Show all folders" : "Rādīt visas mapes",
+    "Collapse folders" : "Sakļaut mapes",
     "Loading …" : "Ielādē…",
     "Delete folder" : "Izdzēst mapi",
     "An error occurred, unable to rename the mailbox." : "Atgadījās kļūda, nevar pārdēvēt pastkasti.",
@@ -136,7 +140,7 @@ OC.L10N.register(
     "Operator" : "Operators",
     "contains" : "saturs",
     "matches" : "atbilst",
-    "Priority" : "Prioritāte",
+    "Priority" : "Svarīgums",
     "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
     "Client ID" : "Klienta ID",
@@ -146,6 +150,9 @@ OC.L10N.register(
     "Valid until" : "Derīgs līdz",
     "Certificate" : "Sertifikāts",
     "Submit" : "Iesniegt",
+    "Group" : "Grupa",
+    "Shared" : "Koplietots",
+    "Shares" : "Koplietots",
     "Account connected" : "Konts sasaistīts",
     "You can close this window" : "Šo logu var aizvērt.",
     "Connect your mail account" : "Pievienot savu e-pasta kontu",
@@ -168,8 +175,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s",
-    "Search in mailbox" : "Meklēt pastkastē",
-    "Actions" : "Darbības"
+    "Continue to %s" : "Turpināt %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
