@@ -102,6 +102,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Folosiți avataruri Gravatar și favicon",
     "Register as application for mail links" : "Înregistrează ca aplicație pentru\nlink-urile de mail",
     "Register" : "Înregistrează-te",
+    "Shared with me" : "Partajat cu mine",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permiteți aplicației să colecteze date despre interacțiunile dumneavoastră. Aplicația se va adapta preferințelor dumneavoastră în funcție de aceste date. Datele sunt stocate doar local.",
     "Trusted senders" : "Expeditori de încredere",
     "Manage S/MIME certificates" : "Administrează certificatele  S/MIME",
@@ -118,6 +119,7 @@ OC.L10N.register(
     "Search" : "Caută",
     "Send" : "Trimite",
     "Refresh" : "Reîmprospătează",
+    "Ok" : "Ok",
     "No certificate" : "Niciun certificat",
     "Certificate updated" : "Certificatul a fost actualizat",
     "Could not update certificate" : "Nu s-a putut actualiza certificatul",
@@ -210,7 +212,6 @@ OC.L10N.register(
     "Back" : "Înapoi",
     "Set custom snooze" : "Setare amânare particularizată",
     "Edit as new message" : "Editează ca mesaj nou",
-    "Create event" : "Creează eveniment",
     "Create task" : "Creează sarcină",
     "Download message" : "Descarcă mesajul",
     "Load more" : "Încarcă mai mult",
@@ -226,10 +227,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editează eticheta pentru {number}","Editează etichetele pentru {number}","Editează etichetele pentru {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Mută {number} conversație","Mută {number} conversații","Mută {number} conversații"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Redirecționează {number} ca atașament","Redirecționează {number} ca atașament","Redirecționează {number} ca atașament"],
+    "Mark as unread" : "Marchează ca necitit",
+    "Mark as read" : "Marchează ca citit",
     "Report this bug" : "Raportați acest incident",
     "Event created" : "Evenimentul a fost  creat",
     "Could not create event" : "Evenimentul nu a putut fi creat",
+    "Create event" : "Creează eveniment",
     "All day" : "Toată ziua",
+    "Attendees" : "Participanți",
     "Select calendar" : "Selectează calendarul",
     "Description" : "Descriere",
     "Create" : "Crează",
@@ -256,6 +261,7 @@ OC.L10N.register(
     "Remove" : "Elimină",
     "email" : "email",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nu aveți permisiunea să mutați mesajul în folderul de arhivare și/sau șterge mesajul din folderul curent",
+    "Today" : "Azi",
     "Loading messages …" : "Se încarcă mesajele ...",
     "Choose target folder" : "Alege directorul destinație",
     "No more submailboxes in here" : "Nu mai sunt subfoldere",
@@ -418,8 +424,6 @@ OC.L10N.register(
     "Reply to sender only" : "Răspunde doar expeditorului",
     "Mark as unfavorite" : "Elimină de la favorite",
     "Mark as favorite" : "Marchează ca favorit",
-    "Mark as unread" : "Marchează ca necitit",
-    "Mark as read" : "Marchează ca citit",
     "Unsubscribe via link" : "Dezabonare prin link",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Dezabonare va opri mesajele din lista de distribuție {sender}",
     "Send unsubscribe email" : "Trimite email de dezabonare",
@@ -468,6 +472,10 @@ OC.L10N.register(
     "Delete certificate" : "Șterge certificatul",
     "Certificate" : "Certificat",
     "Submit" : "Trimite",
+    "Guest" : "Invitat",
+    "Group" : "Grup",
+    "Shared" : "Partajat",
+    "Shares" : "Partajări",
     "Account connected" : "Cont conectat",
     "You can close this window" : "Puteți închide fereastra",
     "Connect your mail account" : "Conectați-vă contul de mail",
@@ -501,30 +509,6 @@ OC.L10N.register(
     "Redirect" : "Deviere",
     "The link leads to %s" : "Link-ul duce la %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Dacă nu doriți să vizitați acea pagină, vă puteți întoarce la <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "Continuă către %s",
-    "Mailbox search" : "Căutare mail",
-    "No messages in this mailbox" : "Nu există mesaje",
-    "No trash mailbox configured" : "Nu este configurat un folder pentru mesajele șterse",
-    "Draft: " : "Schiță:",
-    "To archive a message please configure an archive mailbox in account settings" : "Pentru arhivarea mesajelor configurați un folder de arhivare în setările contului",
-    "Could not open mailbox" : "Cutia poștală nu se poate deschide",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Se indexează mesajele. Aceasta poate dura ceva mai mult pentru cutiile poștale mai încărcate.",
-    "Choose target mailbox" : "Selectați folderul destinație",
-    "Show only subscribed mailboxes" : "Arată doar căsuțele abonate",
-    "Add mailbox" : "Adaugă mailbox",
-    "Mailbox name" : "Nume mailbox",
-    "Show all subscribed mailboxes" : "Afișează toate căsuțele abonate",
-    "Show all mailboxes" : "Afișează toate folderele",
-    "Collapse mailboxes" : "Restrânge folderele",
-    "Clear mailbox" : "Golește folderul",
-    "The mailbox and all messages in it will be deleted." : "Se ca șterge folderul și toate mesajele.",
-    "Delete mailbox" : "Șterge folderul",
-    "Delete mailbox {name}" : "Șterge mailbox {name}",
-    "Mark all messages of this mailbox as read" : "Marchează toate mesajele din acest folder ca citite",
-    "Add submailbox" : "Adaugă subfolder",
-    "Move mailbox" : "Mută cutia poștală",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nu este configurat un folder pentru mesaje trimise. Selectați unul în setările contului.",
-    "Search in mailbox" : "Cautare în folder",
-    "Actions" : "Acțiuni"
+    "Continue to %s" : "Continuă către %s"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
