@@ -98,6 +98,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
     "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
     "Register" : "Vpis računa",
+    "Shared with me" : "V souporabi z mano",
     "Data collection consent" : "Strinjanje z zbiranjem podatkov",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
     "Trusted senders" : "Zaupanja vredni pošiljatelji",
@@ -115,6 +116,7 @@ OC.L10N.register(
     "Search" : "Iskanje",
     "Send" : "Pošlji",
     "Refresh" : "Osveži",
+    "Ok" : "Sprejemljivo",
     "No certificate" : "Ni potrdil",
     "Certificate updated" : "Potrdilo je posodobljeno",
     "Could not update certificate" : "Potrdila ni mogoče posodobiti",
@@ -204,7 +206,6 @@ OC.L10N.register(
     "More actions" : "Več dejanj",
     "Back" : "Nazaj",
     "Edit as new message" : "Uredi kot novo sporočilo",
-    "Create event" : "Ustvari dogodek",
     "Create task" : "Ustvari nalogo",
     "Download message" : "Prejmi sporočilo",
     "Load more" : "Naloži več",
@@ -215,10 +216,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Odstrani izbiro {number} sporočila","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil"],
     "_Move {number} thread_::_Move {number} threads_" : ["Premakni {number} nit sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Posreduj {number} sporočilo kot prilogo","Posreduj {number} sporočili kot prilogo","Posreduj {number} sporočila kot prilogo","Posreduj {number} sporočil kot prilogo"],
+    "Mark as unread" : "Označi kot neprebrano",
+    "Mark as read" : "Označi kot prebrano",
     "Report this bug" : "Pošlji poročilo o hrošču",
     "Event created" : "Dogodek je ustvarjen",
     "Could not create event" : "Ni mogoče ustvariti dogodka",
+    "Create event" : "Ustvari dogodek",
     "All day" : "Ves dan",
+    "Attendees" : "Udeleženci",
     "Select calendar" : "Izbor koledarja",
     "Description" : "Opis",
     "Create" : "Ustvari",
@@ -246,6 +251,10 @@ OC.L10N.register(
     "Remove" : "Odstrani",
     "email" : "elektronska pošta",
     "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
+    "Last hour" : "Zadnja ura",
+    "Today" : "Danes",
+    "Last week" : "Zadnji teden",
+    "Last month" : "Zadnji mesec",
     "Loading messages …" : "Poteka nalaganje sporočil ...",
     "Choose target folder" : "Izbor ciljne mape",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
@@ -402,8 +411,6 @@ OC.L10N.register(
     "Reply to sender only" : "Odgovori le pošiljatelju",
     "Mark as unfavorite" : "Odstrani oznako priljubljeno",
     "Mark as favorite" : "Označi kot priljubljeno",
-    "Mark as unread" : "Označi kot neprebrano",
-    "Mark as read" : "Označi kot prebrano",
     "The message could not be translated" : "Sporočila ni mogoče prevesti",
     "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
     "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
@@ -498,6 +505,10 @@ OC.L10N.register(
     "Certificate" : "Potrdilo",
     "Private key (optional)" : "Zasebni ključ (izbirno)",
     "Submit" : "Pošlji",
+    "Group" : "Skupina",
+    "Shared" : "V souporabi",
+    "Shares" : "V souporabi",
+    "Insert" : "Vstavi",
     "Account connected" : "Račun je povezan",
     "Connect your mail account" : "Povežite svoj elektronski račun",
     "All" : "Vse",
@@ -530,28 +541,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Če vas sistem v nekaj sekundah ne preusmeri samodejno, pritisnite na to mesto.",
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
-    "Continue to %s" : "Nadaljuj na %s",
-    "Mailbox search" : "Iskanje po poštnem predalu",
-    "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
-    "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
-    "Draft: " : "Osnutek:",
-    "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
-    "Choose target mailbox" : "Izbor ciljnega poštnega predala",
-    "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
-    "Add mailbox" : "Dodaj poštni predal",
-    "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
-    "Show all mailboxes" : "Pokaži vse poštne predale",
-    "Collapse mailboxes" : "Skrči poštne predale",
-    "Clear mailbox" : "Počisti poštni predal",
-    "The mailbox and all messages in it will be deleted." : "Poštni predal in vsa vključena sporočila bodo izbrisana.",
-    "Delete mailbox" : "Izbriši poštni predal",
-    "Delete mailbox {name}" : "Izbriši poštni predal {name}",
-    "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
-    "Add submailbox" : "Dodaj podrejeni poštni predal",
-    "Move mailbox" : "Premakni poštni predal",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ni določenega predala za pošiljanje. Izberite ga med nastavitvami računa.",
-    "Search in mailbox" : "Preišči poštni predal",
-    "Actions" : "Dejanja"
+    "Continue to %s" : "Nadaljuj na %s"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
